@@ -1,5 +1,7 @@
-; Dec 18 2009
+; Modification of mode9 with *split-global-disjunctions* t
+; May 11 2010
 ; Chad E Brown
+(setq *split-global-disjunctions* t) ; the only difference from mode9
 (setq *call-period* 100)
 (setq *minisat-timeout* 1)
 (setq *exists-delay* 0)
@@ -18,4 +20,3 @@
 (setq *enum-false* 100)
 (setq *enum-choice* 100)
 (setq *enum-eq* 100)
-(setq *choice-as-default* t)
\ No newline at end of file
